package main

import (
	"os"

	"git.coopgo.io/coopgo-platform/geography/handlers/admin"
	"github.com/paulmach/orb"
	"github.com/paulmach/orb/geojson"
	"github.com/rs/zerolog"
	"github.com/rs/zerolog/log"
)

func main() {
	zerolog.TimeFieldFormat = zerolog.TimeFormatUnix
	cfg, err := ReadConfig()
	if err != nil {
		panic(err)
	}
	var (
		service_name = cfg.GetString("name")
		grpc_enable  = cfg.GetBool("services.grpc.enable")
		dev_env      = cfg.GetBool("dev_env")
	)
	if dev_env {
		log.Logger = log.Output(zerolog.ConsoleWriter{Out: os.Stderr})
	}
	log.Info().Str("service name", service_name).Bool("grpc_enabled", grpc_enable).Bool("dev_env", dev_env).Msg("Running service")

	adminIdx, err := admin.NewAdminIndex(cfg)

	geo := geojson.NewFeature(orb.Point{7.11667, 43.583328})
	res, err := adminIdx.GeoSearch(geo)

	for layer, f := range res {
		log.Info().Str("layer", layer).Str("code", f.Properties.MustString("code")).Str("nom", f.Properties.MustString("nom")).Msg("result")
	}
}
